@@ -26,7 +26,7 @@ DeltaMethod <- function(par, fct, vcov, delta, ...){
   savepar <- par
   value1 <- theta(par)
   partial <- matrix(0,nrow=length(par),ncol=length(value1))
-  for(i in 1:length(par)){
+  for(i in seq_along(par)){
     # Store the original parameters into par and then adjust the
     # ith parameter by adding the proportion based on delta
     if(savepar[i]!=0){
